#!/bin/tcsh

# This script starts the Robo_Gunners_2009 team. When player numbers are 
# supplied before the (optional) host-name argument only
# these players are started, otherwise all players are started.
# Usage:   start.sh <player-numbers> <host-name>
#
# Example: start.sh              all players default host
# Example: start.sh machine      all players on host 'machine'
# Example: start.sh localhost    all players on localhost
# Example: start.sh 127.0.0.1    all players on 127.0.0.1
# Example: start.sh 1 2 3 4      players 1-4 on default host
# Example: start.sh 1 2 remote   players 1-2 on host 'remote'
# Example: start.sh 9 10 remote  players 9-10 on host remote
# Example: start.sh 0            start coach on default host

set wait  = 0
set host  = "localhost"
set team  = "RoboKick" 
set dir   = "/home/robokick"
set prog  = "${dir}/RoboGunners_player"
set coach = "${dir}/RoboGunners_coach"
set pconf = "${dir}/player.conf"
set fconf = "${dir}/formations.conf"
set lconf = "${dir}/log.conf"

echo "**************************************************************************"
echo "* RoboGunners 2003 - Shahid Hojati Inqiury School of NajafAbad, Esfahan  *"
echo "* Created by:           Ali Ekramian                                     *"
echo "* Research Coordinator: Ali Ekramian                                     *" 
echo "* Team Coordinator:     Ali Ekramian                                     *"
echo "* Copyright 2000-2001.  Jelle Kok and Remco de Boer                      *"
echo "* Copyright 2001-2002.  Jelle Kok                                        *"
echo "* Copyright 2002-2003.  Jelle Kok                                        *"
echo "* Copyright 2007-2008.  Jelle Kok and Mahdi Nami Damirchi                *"
echo "* All rights reserved.                                                   *"
echo "**************************************************************************"

#first check if the last two supplied arguments are no numbers and represent
#<host-name> or <host-name> <team-name>
if( $#argv > 0 && ($argv[$#argv] !~ [0123456789]* || $argv[$#argv] =~ *.* ) ) then
  @ second_last = $#argv - 1  
  if( $#argv > 1 && ($argv[$second_last] !~ [0123456789]* || $argv[$second_last] =~ *.* ) ) then
      set host = $argv[$second_last]
      set team = $argv[$#argv]
  else
      set host = $argv[$#argv]
  endif
endif

#then if first argument is a number, start only the players with the numbers
#as supplied on the prompt, otherwise start all players.
if( $1 =~ [0123456789]* && $1 !~ *.* ) then
  echo "$argv[$#argv]"
    echo "$1"
  foreach arg ($argv)
    if( $arg =~ [123456789]* && $arg !~ *.*) then
      ${prog} -host ${host} -team ${team} -num ${arg} -f ${fconf} -c ${pconf} -o ${lconf}&
      sleep $wait
    else if( $arg =~ [0]* ) then
      sleep 2
      ${coach} -host ${host} -team ${team} -f ${fconf} &
    endif
  end
else
  set i = 1
  while ( ${i} <12 )
    ${prog} -host ${host} -team ${team} -number ${i} -f ${fconf} -c ${pconf} -log 101 -o ${lconf} &
    sleep $wait
    @ i++
  end
  sleep 2
  ${coach} -host ${host} -team ${team} -f ${fconf}  &
endif

